@@ -22,13 +22,14 @@
 package org.ojalgo.matrix.decomposition;
 
 import java.util.ArrayList;
+import java.util.Collections;
 import java.util.Comparator;
 import java.util.List;
 import java.util.Optional;
 
 import org.ojalgo.ProgrammingError;
 import org.ojalgo.array.Array1D;
-import org.ojalgo.array.DenseArray;
+import org.ojalgo.array.PlainArray;
 import org.ojalgo.matrix.Provider2D;
 import org.ojalgo.matrix.store.GenericStore;
 import org.ojalgo.matrix.store.MatrixStore;
@@ -113,8 +114,7 @@ public interface Eigenvalue<N extends Comparable<N>> extends MatrixDecomposition
             final int prime = 31;
             int result = 1;
             result = prime * result + (value == null ? 0 : value.hashCode());
-            result = prime * result + (vector == null ? 0 : vector.hashCode());
-            return result;
+            return prime * result + (vector == null ? 0 : vector.hashCode());
         }
 
     }
@@ -218,7 +218,7 @@ public interface Eigenvalue<N extends Comparable<N>> extends MatrixDecomposition
 
     }
 
-    Factory<ComplexNumber> COMPLEX = new Factory<ComplexNumber>() {
+    Factory<ComplexNumber> COMPLEX = new Factory<>() {
 
         @Override
         public Eigenvalue<ComplexNumber> make(final Structure2D typical, final boolean hermitian) {
@@ -249,11 +249,11 @@ public interface Eigenvalue<N extends Comparable<N>> extends MatrixDecomposition
         return retVal;
     };
 
-    Factory<Double> PRIMITIVE = new Factory<Double>() {
+    Factory<Double> PRIMITIVE = new Factory<>() {
 
         @Override
         public Eigenvalue<Double> make(final Structure2D typical) {
-            if (8192L < typical.countColumns() && typical.count() <= DenseArray.MAX_ARRAY_SIZE) {
+            if (8192L < typical.countColumns() && typical.count() <= PlainArray.MAX_SIZE) {
                 return new DynamicEvD.Primitive();
             }
             return new RawEigenvalue.Dynamic();
@@ -262,12 +262,12 @@ public interface Eigenvalue<N extends Comparable<N>> extends MatrixDecomposition
         @Override
         public Eigenvalue<Double> make(final Structure2D typical, final boolean hermitian) {
             if (hermitian) {
-                if (8192L < typical.countColumns() && typical.count() <= DenseArray.MAX_ARRAY_SIZE) {
+                if (8192L < typical.countColumns() && typical.count() <= PlainArray.MAX_SIZE) {
                     return new HermitianEvD.Primitive();
                 }
                 return new RawEigenvalue.Symmetric();
             }
-            if (8192L < typical.countColumns() && typical.count() <= DenseArray.MAX_ARRAY_SIZE) {
+            if (8192L < typical.countColumns() && typical.count() <= PlainArray.MAX_SIZE) {
                 return new GeneralEvD.Primitive();
             }
             return new RawEigenvalue.General();
@@ -285,7 +285,7 @@ public interface Eigenvalue<N extends Comparable<N>> extends MatrixDecomposition
 
     };
 
-    Factory<Quaternion> QUATERNION = new Factory<Quaternion>() {
+    Factory<Quaternion> QUATERNION = new Factory<>() {
 
         @Override
         public Eigenvalue<Quaternion> make(final Structure2D typical, final boolean hermitian) {
@@ -304,7 +304,7 @@ public interface Eigenvalue<N extends Comparable<N>> extends MatrixDecomposition
 
     };
 
-    Factory<RationalNumber> RATIONAL = new Factory<RationalNumber>() {
+    Factory<RationalNumber> RATIONAL = new Factory<>() {
 
         @Override
         public Eigenvalue<RationalNumber> make(final Structure2D typical, final boolean hermitian) {
@@ -335,12 +335,7 @@ public interface Eigenvalue<N extends Comparable<N>> extends MatrixDecomposition
         return Access2D.equals(tmpStore1, tmpStore2, context);
     }
 
-    /**
-     * @deprecated With Java 9 this will be made private. Use {@link #getEigenvectors()} or
-     *             {@link #getEigenpair(int)} instead.
-     */
-    @Deprecated
-    default void copyEigenvector(final int index, final Array1D<ComplexNumber> destination) {
+    private void copyEigenvector(final int index, final Array1D<ComplexNumber> destination) {
 
         final MatrixStore<N> tmpV = this.getV();
         final MatrixStore<N> tmpD = this.getD();
@@ -382,7 +377,7 @@ public interface Eigenvalue<N extends Comparable<N>> extends MatrixDecomposition
 
         final long dim = this.getV().countColumns();
 
-        final Array1D<ComplexNumber> vector = Array1D.COMPLEX.make(dim);
+        final Array1D<ComplexNumber> vector = Array1D.C128.make(dim);
         this.copyEigenvector(index, vector);
 
         final Array1D<ComplexNumber> values = this.getEigenvalues();
@@ -405,7 +400,7 @@ public interface Eigenvalue<N extends Comparable<N>> extends MatrixDecomposition
             retVal.add(this.getEigenpair(i));
         }
 
-        retVal.sort(null);
+        Collections.sort(retVal);
 
         return retVal;
     }
