@@ -27,11 +27,11 @@ import java.util.List;
 import org.ojalgo.ProgrammingError;
 import org.ojalgo.array.Array1D;
 import org.ojalgo.array.Array2D;
+import org.ojalgo.array.ArrayC128;
+import org.ojalgo.array.ArrayH256;
+import org.ojalgo.array.ArrayQ128;
 import org.ojalgo.array.BasicArray;
-import org.ojalgo.array.ComplexArray;
 import org.ojalgo.array.DenseArray;
-import org.ojalgo.array.QuaternionArray;
-import org.ojalgo.array.RationalArray;
 import org.ojalgo.array.ScalarArray;
 import org.ojalgo.array.operation.*;
 import org.ojalgo.concurrent.DivideAndConquer;
@@ -337,9 +337,9 @@ public final class GenericStore<N extends Scalar<N>> extends ScalarArray<N> impl
 
     }
 
-    public static final PhysicalStore.Factory<ComplexNumber, GenericStore<ComplexNumber>> COMPLEX = new GenericStore.Factory<>(ComplexArray.FACTORY);
-    public static final PhysicalStore.Factory<Quaternion, GenericStore<Quaternion>> QUATERNION = new GenericStore.Factory<>(QuaternionArray.FACTORY);
-    public static final PhysicalStore.Factory<RationalNumber, GenericStore<RationalNumber>> RATIONAL = new GenericStore.Factory<>(RationalArray.FACTORY);
+    public static final PhysicalStore.Factory<ComplexNumber, GenericStore<ComplexNumber>> COMPLEX = new GenericStore.Factory<>(ArrayC128.FACTORY);
+    public static final PhysicalStore.Factory<Quaternion, GenericStore<Quaternion>> QUATERNION = new GenericStore.Factory<>(ArrayH256.FACTORY);
+    public static final PhysicalStore.Factory<RationalNumber, GenericStore<RationalNumber>> RATIONAL = new GenericStore.Factory<>(ArrayQ128.FACTORY);
 
     public static <N extends Scalar<N>> GenericStore<N> wrap(final GenericStore.Factory<N> factory, final N... data) {
         return new GenericStore<>(factory, data.length, 1, data);
