@@ -27,8 +27,8 @@ import java.util.List;
 import org.ojalgo.ProgrammingError;
 import org.ojalgo.array.Array1D;
 import org.ojalgo.array.Array2D;
+import org.ojalgo.array.ArrayR032;
 import org.ojalgo.array.DenseArray;
-import org.ojalgo.array.Primitive32Array;
 import org.ojalgo.array.operation.FillMatchingSingle;
 import org.ojalgo.array.operation.RotateLeft;
 import org.ojalgo.array.operation.RotateRight;
@@ -64,13 +64,13 @@ import org.ojalgo.type.NumberDefinition;
  *
  * @author apete
  */
-public final class Primitive32Store extends Primitive32Array implements PhysicalStore<Double> {
+public final class Primitive32Store extends ArrayR032 implements PhysicalStore<Double> {
 
     public static final PhysicalStore.Factory<Double, Primitive32Store> FACTORY = new PrimitiveFactory<Primitive32Store>() {
 
         @Override
         public DenseArray.Factory<Double> array() {
-            return Primitive32Array.FACTORY;
+            return ArrayR032.FACTORY;
         }
 
         public Primitive32Store columns(final Access1D<?>... source) {
@@ -816,11 +816,6 @@ public final class Primitive32Store extends Primitive32Array implements Physical
         return myUtility.sliceRow(row, col);
     }
 
-    @Override
-    public String toString() {
-        return Access2D.toString(this);
-    }
-
     public void substituteBackwards(final Access2D<Double> body, final boolean unitDiagonal, final boolean conjugated, final boolean hermitian) {
 
         final int tmpRowDim = myRowDim;
@@ -877,6 +872,11 @@ public final class Primitive32Store extends Primitive32Array implements Physical
         return myUtility.toRawCopy2D();
     }
 
+    @Override
+    public String toString() {
+        return Access2D.toString(this);
+    }
+
     public void transformLeft(final Householder<Double> transformation, final int firstColumn) {
         HouseholderLeft.call(data, myRowDim, firstColumn, Primitive32Store.cast(transformation));
     }
