@@ -28,17 +28,22 @@ import java.io.FileInputStream;
 import java.io.FileOutputStream;
 import java.io.IOException;
 import java.io.InputStream;
+import java.io.OutputStream;
 import java.math.BigDecimal;
 import java.util.*;
+import java.util.function.Consumer;
 import java.util.function.Function;
+import java.util.function.Predicate;
 import java.util.stream.Stream;
 
 import org.ojalgo.ProgrammingError;
 import org.ojalgo.array.Array1D;
-import org.ojalgo.array.Primitive64Array;
+import org.ojalgo.array.ArrayR064;
 import org.ojalgo.function.constant.BigMath;
 import org.ojalgo.netio.BasicLogger;
+import org.ojalgo.netio.InMemoryFile;
 import org.ojalgo.netio.ToFileWriter;
+import org.ojalgo.optimisation.Optimisation.Integration;
 import org.ojalgo.optimisation.convex.ConvexSolver;
 import org.ojalgo.optimisation.integer.IntegerSolver;
 import org.ojalgo.optimisation.linear.LinearSolver;
@@ -55,17 +60,14 @@ import org.ojalgo.type.context.NumberContext;
  * {@linkplain Expression#lower(Comparable)}, {@linkplain Expression#upper(Comparable)} or
  * {@linkplain Expression#level(Comparable)}. An expression or variable is made part of (contributing to) the
  * objective function by setting a contribution weight. Use {@linkplain Expression#weight(Comparable)}.
- * </p>
  * <p>
  * You may think of variables as simple (the simplest possible) expressions, and of expressions as weighted
  * combinations of variables. They are both model entities and it is as such they can be turned into
  * constraints and set to contribute to the objective function. Alternatively you may choose to disregard the
  * fact that variables are model entities and simply treat them as index values. In this case everything
  * (constraints and objective) needs to be defined using expressions.
- * </p>
  * <p>
  * Basic instructions:
- * </p>
  * <ol>
  * <li>Define (create) a set of variables. Set contribution weights and lower/upper limits as needed.</li>
  * <li>Create a model using that set of variables.</li>
@@ -78,7 +80,6 @@ import org.ojalgo.type.context.NumberContext;
  * various solvers describe requirements on input formats and similar. This is handled for you and should
  * absolutely NOT be considered here! Compared to using the various solvers directly this class actually does
  * something for you:
- * </p>
  * <ol>
  * <li>You can model your problems without worrying about specific solver requirements.</li>
  * <li>It knows which solver to use.</li>
@@ -103,6 +104,52 @@ import org.ojalgo.type.context.NumberContext;
  */
 public final class ExpressionsBasedModel implements Optimisation.Model {
 
+    /**
+     * Counts of different kinds of model entities.
+     *
+     * @author apete
+     */
+    public static final class Description {
+
+        public final int nbEqualityBounds;
+        public final int nbEqualityConstraints;
+        public final int nbIntegerVariables;
+        public final int nbLowerBounds;
+        public final int nbLowerConstraints;
+        public final int nbNegativeVariables;
+        public final int nbPositiveVariables;
+        public final int nbUpperBounds;
+        public final int nbUpperConstraints;
+        public final int nbVariables;
+
+        Description(final int varTotal, final int varPositive, final int varNegative, final int varInteger, final int nbLoBound, final int nbUpBound,
+                final int nbEqBound, final int nbLoCnstr, final int nbUpCnstr, final int nbEqCnstr) {
+
+            super();
+
+            nbLowerBounds = nbLoBound;
+            nbUpperBounds = nbUpBound;
+            nbEqualityBounds = nbEqBound;
+
+            nbLowerConstraints = nbLoCnstr;
+            nbUpperConstraints = nbUpCnstr;
+            nbEqualityConstraints = nbEqCnstr;
+
+            nbIntegerVariables = varInteger;
+            nbNegativeVariables = varNegative;
+            nbPositiveVariables = varPositive;
+            nbVariables = varTotal;
+        }
+
+        /**
+         * The total number of constraints
+         */
+        public int constraints() {
+            return nbEqualityConstraints + nbLowerConstraints + nbUpperConstraints;
+        }
+
+    }
+
     public enum FileFormat {
 
         EBM, MPS;
@@ -141,66 +188,97 @@ public final class ExpressionsBasedModel implements Optimisation.Model {
     public static abstract class Integration<S extends Optimisation.Solver> implements Optimisation.Integration<ExpressionsBasedModel, S> {
 
         /**
-         * @see org.ojalgo.optimisation.Optimisation.Integration#extractSolverState(org.ojalgo.optimisation.Optimisation.Model)
+         * @see Optimisation.Integration#extractSolverState(Optimisation.Model)
          */
         public final Result extractSolverState(final ExpressionsBasedModel model) {
             return this.toSolverState(model.getVariableValues(), model);
         }
 
+        /**
+         * The required behaviour here depends on how {@link #build(Optimisation.Model)} is implemented, and
+         * is the reverse mapping of {@link #toSolverState(Optimisation.Result, ExpressionsBasedModel)}.
+         *
+         * @see Optimisation.Integration#toModelState(Optimisation.Result, Optimisation.Model)
+         * @see #toSolverState(Optimisation.Result, ExpressionsBasedModel)
+         */
         public Result toModelState(final Result solverState, final ExpressionsBasedModel model) {
 
-            final int numbVariables = model.countVariables();
-
-            if (this.isSolutionMapped()) {
-
-                final List<Variable> freeVariables = model.getFreeVariables();
-                final Set<IntIndex> fixedVariables = model.getFixedVariables();
-
-                if (solverState.count() != freeVariables.size()) {
-                    throw new IllegalStateException();
-                }
-
-                final Primitive64Array modelSolution = Primitive64Array.make(numbVariables);
-
-                for (final IntIndex fixedIndex : fixedVariables) {
-                    modelSolution.set(fixedIndex.index, model.getVariable(fixedIndex.index).getValue());
-                }
-
-                for (int f = 0; f < freeVariables.size(); f++) {
-                    final int freeIndex = model.indexOf(freeVariables.get(f));
-                    modelSolution.set(freeIndex, solverState.doubleValue(f));
-                }
-
-                return new Result(solverState.getState(), modelSolution);
+            if (!this.isSolutionMapped()) {
+                return solverState;
             }
 
-            if (solverState.count() != numbVariables) {
-                throw new IllegalStateException();
+            List<Variable> freeVariables = model.getFreeVariables();
+            Set<IntIndex> fixedVariables = model.getFixedVariables();
+            int nbFreeVars = freeVariables.size();
+            int nbModelVars = model.countVariables();
+
+            ArrayR064 modelSolution = ArrayR064.make(nbModelVars);
+
+            for (int i = 0; i < nbFreeVars; i++) {
+                modelSolution.set(model.indexOf(freeVariables.get(i)), solverState.doubleValue(i));
             }
 
-            return solverState;
+            for (IntIndex fixed : fixedVariables) {
+                modelSolution.set(fixed.index, model.getVariable(fixed.index).getValue());
+            }
+
+            return new Result(solverState.getState(), modelSolution);
         }
 
+        /**
+         * The required behaviour here depends on how {@link #build(Optimisation.Model)} is implemented!
+         * <p>
+         * If {@link #isSolutionMapped()} returns false this implementation does nothing – the input model
+         * state is returned as the solver state.
+         * <p>
+         * If {@link #isSolutionMapped()} returns true the standard mapping is applied - just accounting for
+         * that not all model variables are present in the solver. Variables that are fixed, by the presolver
+         * in the model, are typically not present in the solver.
+         * <p>
+         * If mapping needs to be performed, but it is not the standard mapping, then this method needs to be
+         * overridden for the specific implementation. For instance an LP simplex solver that separates
+         * between the positive and negative parts of variables need to do that. In that case
+         * {@link #isSolutionMapped()} is irrelevant, but should return true for good measure.
+         *
+         * @see Optimisation.Integration#toSolverState(Optimisation.Result, Optimisation.Model)
+         */
         public Result toSolverState(final Result modelState, final ExpressionsBasedModel model) {
 
             if (!this.isSolutionMapped()) {
-
                 return modelState;
             }
-            final List<Variable> tmpFreeVariables = model.getFreeVariables();
-            final int numbFreeVars = tmpFreeVariables.size();
 
-            final Primitive64Array solverSolution = Primitive64Array.make(numbFreeVars);
+            List<Variable> freeVariables = model.getFreeVariables();
+            int nbFreeVars = freeVariables.size();
 
-            for (int i = 0; i < numbFreeVars; i++) {
-                final Variable variable = tmpFreeVariables.get(i);
-                final int modelIndex = model.indexOf(variable);
+            ArrayR064 solverSolution = ArrayR064.make(nbFreeVars);
+
+            for (int i = 0; i < nbFreeVars; i++) {
+                Variable variable = freeVariables.get(i);
+                int modelIndex = model.indexOf(variable);
                 solverSolution.set(i, modelState.doubleValue(modelIndex));
             }
 
             return new Result(modelState.getState(), solverSolution);
         }
 
+        /**
+         * Use this to limit the cases where this {@link Integration} would be used.
+         * <p>
+         * Returns a new Integration instance where the supplied {@link Predicate} needs to test true in
+         * addition to the underlying {@link #isCapable(Optimisation.Model)}.
+         */
+        public final ExpressionsBasedModel.Integration<S> withCapabilityPredicate(final Predicate<ExpressionsBasedModel> capabilityPredicate) {
+            return new ConfiguredIntegration<>(this, capabilityPredicate, null);
+        }
+
+        /**
+         * Intercept and modify the {@link Optimisation.Options} instance before building the solver.
+         */
+        public final ExpressionsBasedModel.Integration<S> withOptionsModifier(final Consumer<Optimisation.Options> optionsModifier) {
+            return new ConfiguredIntegration<>(this, null, optionsModifier);
+        }
+
         /**
          * @return The index with which one can reference parameters related to this variable in the solver.
          */
@@ -461,17 +539,6 @@ public final class ExpressionsBasedModel implements Optimisation.Model {
         ExpressionsBasedModel.addPresolver(Presolvers.REDUNDANT_CONSTRAINT);
     }
 
-    /**
-     * Add a solver that will be used for problem types the built-in solvers cannot handle as defined by
-     * {@link Integration#isCapable(org.ojalgo.optimisation.Optimisation.Model)}.
-     *
-     * @deprecated v51.2.0 Use {@link #addSolver(Integration<?>)} instead
-     */
-    @Deprecated
-    public static boolean addFallbackSolver(final Integration<?> integration) {
-        return ExpressionsBasedModel.addIntegration(integration);
-    }
-
     /**
      * Add an integration for a solver that will be used rather than the built-in solvers
      */
@@ -479,16 +546,6 @@ public final class ExpressionsBasedModel implements Optimisation.Model {
         return INTEGRATIONS.add(integration);
     }
 
-    /**
-     * Add a solver that will be used rather than the built-in solvers
-     *
-     * @deprecated v51.2.0 Use {@link #addSolver(Integration<?>)} instead
-     */
-    @Deprecated
-    public static boolean addPreferredSolver(final Integration<?> integration) {
-        return ExpressionsBasedModel.addIntegration(integration);
-    }
-
     public static boolean addPresolver(final Presolver presolver) {
         return PRESOLVERS.add(presolver);
     }
@@ -786,6 +843,51 @@ public final class ExpressionsBasedModel implements Optimisation.Model {
         return myVariables.size();
     }
 
+    /**
+     * Counts variables and expressions of different categories.
+     */
+    public Description describe() {
+
+        int nbUpCnstr = 0;
+        int nbUpBound = 0;
+        int nbLoCnstr = 0;
+        int nbLoBound = 0;
+        int nbEqCnstr = 0;
+        int nbEqBound = 0;
+
+        for (Variable variable : myVariables) {
+            if (variable.isLowerConstraint()) {
+                nbLoBound++;
+            }
+            if (variable.isUpperConstraint()) {
+                nbUpBound++;
+            }
+            if (variable.isEqualityConstraint()) {
+                nbEqBound++;
+            }
+        }
+
+        for (Expression expression : myExpressions.values()) {
+            if (expression.isLowerConstraint()) {
+                nbLoCnstr++;
+            }
+            if (expression.isUpperConstraint()) {
+                nbUpCnstr++;
+            }
+            if (expression.isEqualityConstraint()) {
+                nbEqCnstr++;
+            }
+        }
+
+        VariablesCategorisation variablesCategorisation = new VariablesCategorisation();
+        int nbTotVars = myVariables.size();
+        int nbIntVars = variablesCategorisation.getIntegerVariables(myVariables).size();
+        int nbPosVars = variablesCategorisation.getPositiveVariables(myVariables).size();
+        int nbNegVars = variablesCategorisation.getNegativeVariables(myVariables).size();
+
+        return new Description(nbTotVars, nbPosVars, nbNegVars, nbIntVars, nbLoBound, nbUpBound, nbEqBound, nbLoCnstr, nbUpCnstr, nbEqCnstr);
+    }
+
     @Override
     public void dispose() {
 
@@ -892,7 +994,7 @@ public final class ExpressionsBasedModel implements Optimisation.Model {
 
         State retState = State.UNEXPLORED;
         double retValue = Double.NaN;
-        final Array1D<BigDecimal> retSolution = Array1D.BIG.make(numberOfVariables);
+        final Array1D<BigDecimal> retSolution = Array1D.R128.make(numberOfVariables);
 
         boolean allVarsSomeInfo = true;
 
@@ -1248,7 +1350,7 @@ public final class ExpressionsBasedModel implements Optimisation.Model {
      * This methods validtes model construction only. All the other validate(...) method validates the
      * solution (one way or another).
      *
-     * @see org.ojalgo.optimisation.Optimisation.Model#validate()
+     * @see Optimisation.Model#validate()
      */
     public boolean validate() {
 
@@ -1346,6 +1448,14 @@ public final class ExpressionsBasedModel implements Optimisation.Model {
         }
     }
 
+    public void writeTo(final InMemoryFile file) {
+        try (OutputStream output = file.newOutputStream()) {
+            FileFormatEBM.write(this, output);
+        } catch (IOException cause) {
+            throw new RuntimeException(cause);
+        }
+    }
+
     private Optimisation.Result optimise() {
 
         if (!myShallowCopy && PRESOLVERS.size() > 0) {
@@ -1478,13 +1588,13 @@ public final class ExpressionsBasedModel implements Optimisation.Model {
         if (myInfeasible) {
             return true;
         }
-        for (final Expression tmpExpression : myExpressions.values()) {
-            if (tmpExpression.isInfeasible()) {
+        for (Expression expression : myExpressions.values()) {
+            if (expression.isInfeasible()) {
                 return myInfeasible = true;
             }
         }
-        for (final Variable tmpVariable : myVariables) {
-            if (tmpVariable.isInfeasible()) {
+        for (Variable variable : myVariables) {
+            if (variable.isInfeasible()) {
                 return myInfeasible = true;
             }
         }
