@@ -27,7 +27,8 @@ import java.util.Objects;
 import java.util.Optional;
 
 import org.ojalgo.ProgrammingError;
-import org.ojalgo.array.BigArray;
+import org.ojalgo.array.ArrayR064;
+import org.ojalgo.array.ArrayR128;
 import org.ojalgo.netio.BasicLogger;
 import org.ojalgo.optimisation.integer.IntegerSolver;
 import org.ojalgo.optimisation.integer.IntegerStrategy;
@@ -360,13 +361,35 @@ public interface Optimisation {
     public static final class Result implements Optimisation, Access1D<BigDecimal>, Comparable<Optimisation.Result> {
 
         public static Result of(final double value, final Optimisation.State state, final double... solution) {
-            return new Result(state, value, Access1D.wrap(solution));
+            return new Result(state, value, ArrayR064.wrap(solution));
         }
 
         public static Result of(final Optimisation.State state, final double... solution) {
             return new Result(state, Double.NaN, Access1D.wrap(solution));
         }
 
+        /**
+         * Parse a {@link String}, as produced by the {@link #toString()} method, into a new instance.
+         */
+        public static Result parse(final String result) {
+
+            int indexOfFirstSpace = result.indexOf(" ");
+            int indexOfAtMark = result.indexOf(" @ ");
+
+            String strState = result.substring(0, indexOfFirstSpace);
+            String strValue = result.substring(indexOfFirstSpace + 1, indexOfAtMark);
+            String[] strSolution = result.substring(indexOfAtMark + 5, result.length() - 2).split(", ");
+
+            State state = Optimisation.State.valueOf(strState);
+            double value = Double.parseDouble(strValue);
+            ArrayR128 solution = ArrayR128.make(strSolution.length);
+            for (int i = 0; i < strSolution.length; i++) {
+                solution.set(i, new BigDecimal(strSolution[i]));
+            }
+
+            return new Result(state, value, solution);
+        }
+
         private transient Access1D<?> myMultipliers = null;
         private final Access1D<?> mySolution;
         private final Optimisation.State myState;
@@ -433,9 +456,9 @@ public interface Optimisation {
          * Will round the solution to the given precision
          */
         public Optimisation.Result getSolution(final NumberContext precision) {
-            final Optimisation.State state = this.getState();
-            final double value = this.getValue();
-            final BigArray solution = BigArray.make((int) this.count());
+            Optimisation.State state = this.getState();
+            double value = this.getValue();
+            ArrayR128 solution = ArrayR128.make(this.size());
             for (int i = 0, limit = solution.data.length; i < limit; i++) {
                 solution.set(i, precision.enforce(this.get(i)));
             }
@@ -472,6 +495,10 @@ public interface Optimisation {
             return (int) this.count();
         }
 
+        /**
+         * May potentially be a very long {@link String} as it must contain all variable values. The
+         * {@link String} produced here is (must be) usable by the {@link #parse(String)} method.
+         */
         @Override
         public String toString() {
             return myState + " " + myValue + " @ " + Access1D.toString(mySolution);
@@ -539,7 +566,10 @@ public interface Optimisation {
         FEASIBLE(16),
 
         /**
-         * No solution that complies with all constraints exists
+         * No solution that complies with all constraints exists (found).
+         * <p>
+         * In practise this often means "infeasible or unbounded". The key thing is that with this state the
+         * returned solution is not (known to be) feasible.
          */
         INFEASIBLE(-8),
 
@@ -555,8 +585,18 @@ public interface Optimisation {
 
         /**
          * There's an infinite number of feasible solutions and no bound on the objective function value.
-         * Please note that using this state indicator implies a feasible solution. If a feasible solution has
-         * not been been found you should instead use {@link #INFEASIBLE} or {@link #INVALID}.
+         * <p>
+         * Note that using this state indicator implies a feasible solution! This is not in line with how many
+         * other optimisation tools interpret "unbounded".
+         * <p>
+         * If a feasible solution has not been found, the correct state indicator to use is
+         * {@link #INFEASIBLE} or possibly {@link #INVALID}, {@link} #FAILED} or {@link #APPROXIMATE}.
+         * <p>
+         * If a problem is concluded to be unbounded but a feasible solution has been found, it may still be
+         * preferable to us {@link #FEASIBLE} rather than {@link #UNBOUNDED}.
+         * <p>
+         * There is, unfortunately, no way to convey that a problem is proven to be unbounded without a
+         * feasible solution.
          */
         UNBOUNDED(-32),
 
