@@ -284,141 +284,15 @@ public final class IntegerSolver extends GenericSolver {
         return options.validate || this.isLogProgress() ? CharacterRing.newRingLogger() : null;
     }
 
-    boolean compute(final NodeKey nodeKey, final NodeSolver nodeSolver, final RingLogger nodePrinter, final ModelStrategy strategy) {
+    protected Optimisation.Result buildResult() {
 
-        if (this.isLogDebug()) {
-            nodePrinter.println();
-            nodePrinter.println("Branch&Bound Node");
-            nodePrinter.println(nodeKey.toString());
-            nodePrinter.println(this.toString());
-        }
+        Access1D<?> solution = this.extractSolution();
+        double value = this.evaluateFunction(solution);
+        Optimisation.State state = this.getState();
 
-        if (nodeKey.index >= 0) {
-            nodeKey.enforceBounds(nodeSolver, strategy);
-        }
-
-        Optimisation.Result bestEstimate = this.getBestEstimate();
-        Optimisation.Result nodeResult = nodeSolver.solve(bestEstimate);
-
-        // Increment when/if an iteration was actually performed
-        this.incrementIterationsCount();
-
-        if (this.isLogDebug()) {
-            nodePrinter.println("Node Result: {}", nodeResult);
-        }
-
-        if (!nodeResult.getState().isOptimal()) {
-            if (this.isLogDebug()) {
-                nodePrinter.println("Failed to solve node problem - stop this branch!");
-                IntegerSolver.flush(nodePrinter, myIntegerModel.options.logger_appender);
-            }
-
-            nodeSolver.dispose();
-            if (nodeKey.sequence == 0 && (nodeResult.getState().isUnexplored() || !nodeResult.getState().isValid())) {
-                // return false;
-                return myNodeStatistics.failed();
-            }
-            // return true;
-            strategy.markInfeasible(nodeKey, myBestResultSoFar != null);
-            return myNodeStatistics.infeasible();
-        }
-
-        if (this.isLogDebug()) {
-            nodePrinter.println("Node solved to optimality!");
-        }
-
-        if (options.validate && !nodeSolver.validate(nodeResult, nodePrinter)) {
-            // This should not be possible. There is a bug somewhere.
-            nodePrinter.println("Node solution marked as OPTIMAL, but is actually INVALID/INFEASIBLE/FAILED. Stop this branch!");
-            nodePrinter.println("Integer indices: {}", strategy);
-            nodePrinter.println("Lower bounds: {}", Arrays.toString(nodeKey.copyLowerBounds()));
-            nodePrinter.println("Upper bounds: {}", Arrays.toString(nodeKey.copyUpperBounds()));
-
-            IntegerSolver.flush(nodePrinter, myIntegerModel.options.logger_appender);
-
-            // return false;
-            return myNodeStatistics.failed();
-        }
-
-        int branchIntegerIndex = this.identifyNonIntegerVariable(nodeResult, nodeKey, strategy);
-        double tmpSolutionValue = this.evaluateFunction(nodeResult);
-
-        if (branchIntegerIndex == -1) {
-            if (this.isLogDebug()) {
-                nodePrinter.println("Integer solution! Store it among the others, and stop this branch!");
-            }
-
-            Optimisation.Result tmpIntegerSolutionResult = new Optimisation.Result(Optimisation.State.FEASIBLE, tmpSolutionValue, nodeResult);
-
-            this.markInteger(nodeKey, tmpIntegerSolutionResult, strategy);
-
-            if (this.isLogDebug()) {
-                nodePrinter.println(this.getBestResultSoFar().toString());
-                BasicLogger.debug();
-                BasicLogger.debug(this.toString());
-                // BasicLogger.debug(DaemonPoolExecutor.INSTANCE.toString());
-                IntegerSolver.flush(nodePrinter, myIntegerModel.options.logger_appender);
-            }
-
-            nodeSolver.dispose();
-            return myNodeStatistics.integer();
-
-        }
-        if (this.isLogDebug()) {
-            nodePrinter.println("Not an Integer Solution: " + tmpSolutionValue);
-        }
-
-        double variableValue = nodeResult.doubleValue(strategy.getIndex(branchIntegerIndex));
-
-        if (!strategy.isGoodEnough(myBestResultSoFar, tmpSolutionValue)) {
-            if (this.isLogDebug()) {
-                nodePrinter.println("Can't find better integer solutions - stop this branch!");
-                IntegerSolver.flush(nodePrinter, myIntegerModel.options.logger_appender);
-            }
-
-            nodeSolver.dispose();
-            // return true;
-            return myNodeStatistics.exhausted();
-        }
-        if (this.isLogDebug()) {
-            nodePrinter.println("Still hope, branching on {} @ {} >>> {}", branchIntegerIndex, variableValue,
-                    nodeSolver.getVariable(strategy.getIndex(branchIntegerIndex)));
-            IntegerSolver.flush(nodePrinter, myIntegerModel.options.logger_appender);
-        }
-
-        if (strategy.cutting && nodeKey.sequence % 10L == 0L) {
-            double displacement = nodeKey.getMinimumDisplacement(branchIntegerIndex, variableValue);
-            if (strategy.isCutRatherThanBranch(displacement, myBestResultSoFar != null)) {
-                if (nodeSolver.generateCuts(strategy)) {
-                    return this.compute(nodeKey, nodeSolver, nodePrinter, strategy);
-                }
-                strategy.cutting = false;
-            }
-        }
-
-        NodeKey lowerBranch = nodeKey.createLowerBranch(branchIntegerIndex, variableValue, tmpSolutionValue);
-        NodeKey upperBranch = nodeKey.createUpperBranch(branchIntegerIndex, variableValue, tmpSolutionValue);
-
-        if (!strategy.isDirect(lowerBranch, myBestResultSoFar != null)) {
-            myDeferredNodes.add(lowerBranch);
-            lowerBranch = null;
-        }
-        if (!strategy.isDirect(upperBranch, myBestResultSoFar != null)) {
-            myDeferredNodes.add(upperBranch);
-            upperBranch = null;
-        }
-
-        boolean retVal = true;
-        if (lowerBranch != null) {
-            retVal = retVal && this.compute(lowerBranch, nodeSolver, nodePrinter, strategy);
-        }
-        if (upperBranch != null) {
-            retVal = retVal && this.compute(upperBranch, nodeSolver, nodePrinter, strategy);
-        }
-        return retVal;
+        return new Optimisation.Result(state, value, solution);
     }
 
-    @Override
     protected double evaluateFunction(final Access1D<?> solution) {
         if (myFunction != null && solution != null && myFunction.arity() == solution.count()) {
             return myFunction.invoke(Access1D.asPrimitive1D(solution)).doubleValue();
@@ -426,7 +300,6 @@ public final class IntegerSolver extends GenericSolver {
         return Double.NaN;
     }
 
-    @Override
     protected MatrixStore<Double> extractSolution() {
         return Primitive64Store.FACTORY.columns(this.getBestResultSoFar());
     }
@@ -552,6 +425,146 @@ public final class IntegerSolver extends GenericSolver {
         return retVal;
     }
 
+    boolean compute(final NodeKey nodeKey, final NodeSolver nodeSolver, final RingLogger nodePrinter, final ModelStrategy strategy) {
+
+        if (this.isLogDebug()) {
+            nodePrinter.println();
+            nodePrinter.println("Branch&Bound Node");
+            nodePrinter.println(nodeKey.toString());
+            nodePrinter.println(this.toString());
+        }
+
+        if (nodeKey.index >= 0) {
+            nodeKey.enforceBounds(nodeSolver, strategy);
+        }
+
+        Optimisation.Result bestEstimate = this.getBestEstimate();
+        Optimisation.Result nodeResult = nodeSolver.solve(bestEstimate);
+
+        // Increment when/if an iteration was actually performed
+        this.incrementIterationsCount();
+
+        if (this.isLogDebug()) {
+            nodePrinter.println("Node Result: {}", nodeResult);
+        }
+
+        if (!nodeResult.getState().isOptimal()) {
+            if (this.isLogDebug()) {
+                nodePrinter.println("Failed to solve node problem - stop this branch!");
+                IntegerSolver.flush(nodePrinter, myIntegerModel.options.logger_appender);
+            }
+
+            nodeSolver.dispose();
+            if (nodeKey.sequence == 0 && (nodeResult.getState().isUnexplored() || !nodeResult.getState().isValid())) {
+                // return false;
+                return myNodeStatistics.failed();
+            }
+            // return true;
+            strategy.markInfeasible(nodeKey, myBestResultSoFar != null);
+            return myNodeStatistics.infeasible();
+        }
+
+        if (this.isLogDebug()) {
+            nodePrinter.println("Node solved to optimality!");
+        }
+
+        if (options.validate && !nodeSolver.validate(nodeResult, nodePrinter)) {
+            // This should not be possible. There is a bug somewhere.
+            nodePrinter.println("Node solution marked as OPTIMAL, but is actually INVALID/INFEASIBLE/FAILED. Stop this branch!");
+            nodePrinter.println("Integer indices: {}", strategy);
+            nodePrinter.println("Lower bounds: {}", Arrays.toString(nodeKey.copyLowerBounds()));
+            nodePrinter.println("Upper bounds: {}", Arrays.toString(nodeKey.copyUpperBounds()));
+
+            IntegerSolver.flush(nodePrinter, myIntegerModel.options.logger_appender);
+
+            // return false;
+            return myNodeStatistics.failed();
+        }
+
+        int branchIntegerIndex = this.identifyNonIntegerVariable(nodeResult, nodeKey, strategy);
+        double tmpSolutionValue = this.evaluateFunction(nodeResult);
+
+        if (branchIntegerIndex == -1) {
+            if (this.isLogDebug()) {
+                nodePrinter.println("Integer solution! Store it among the others, and stop this branch!");
+            }
+
+            Optimisation.Result tmpIntegerSolutionResult = new Optimisation.Result(Optimisation.State.FEASIBLE, tmpSolutionValue, nodeResult);
+
+            this.markInteger(nodeKey, tmpIntegerSolutionResult, strategy);
+
+            if (this.isLogDebug()) {
+                nodePrinter.println(this.getBestResultSoFar().toString());
+                BasicLogger.debug();
+                BasicLogger.debug(this.toString());
+                // BasicLogger.debug(DaemonPoolExecutor.INSTANCE.toString());
+                IntegerSolver.flush(nodePrinter, myIntegerModel.options.logger_appender);
+            }
+
+            nodeSolver.dispose();
+            return myNodeStatistics.integer();
+
+        }
+        if (this.isLogDebug()) {
+            nodePrinter.println("Not an Integer Solution: " + tmpSolutionValue);
+        }
+
+        double variableValue = nodeResult.doubleValue(strategy.getIndex(branchIntegerIndex));
+
+        if (!strategy.isGoodEnough(myBestResultSoFar, tmpSolutionValue)) {
+            if (this.isLogDebug()) {
+                nodePrinter.println("Can't find better integer solutions - stop this branch!");
+                IntegerSolver.flush(nodePrinter, myIntegerModel.options.logger_appender);
+            }
+
+            nodeSolver.dispose();
+            // return true;
+            return myNodeStatistics.exhausted();
+        }
+        if (this.isLogDebug()) {
+            nodePrinter.println("Still hope, branching on {} @ {} >>> {}", branchIntegerIndex, variableValue,
+                    nodeSolver.getVariable(strategy.getIndex(branchIntegerIndex)));
+            IntegerSolver.flush(nodePrinter, myIntegerModel.options.logger_appender);
+        }
+
+        if (strategy.cutting && nodeKey.sequence % 10L == 0L) {
+            double displacement = nodeKey.getMinimumDisplacement(branchIntegerIndex, variableValue);
+            if (strategy.isCutRatherThanBranch(displacement, myBestResultSoFar != null)) {
+                if (nodeSolver.generateCuts(strategy)) {
+                    return this.compute(nodeKey, nodeSolver, nodePrinter, strategy);
+                }
+                strategy.cutting = false;
+            }
+        }
+
+        NodeKey lowerBranch = nodeKey.createLowerBranch(branchIntegerIndex, variableValue, tmpSolutionValue);
+        NodeKey upperBranch = nodeKey.createUpperBranch(branchIntegerIndex, variableValue, tmpSolutionValue);
+
+        if (!strategy.isDirect(lowerBranch, myBestResultSoFar != null)) {
+            myDeferredNodes.add(lowerBranch);
+            lowerBranch = null;
+        }
+        if (lowerBranch != null || !strategy.isDirect(upperBranch, myBestResultSoFar != null)) {
+            myDeferredNodes.add(upperBranch);
+            upperBranch = null;
+        }
+
+        if (lowerBranch != null && upperBranch != null) {
+            // Node model data is reused when continuing down in the same thread.
+            // Can't do 2 branches in the same thread, using the same parent model.
+            throw new IllegalStateException();
+        }
+
+        boolean retVal = true;
+        if (lowerBranch != null) {
+            retVal = retVal && this.compute(lowerBranch, nodeSolver, nodePrinter, strategy);
+        }
+        if (upperBranch != null) {
+            retVal = retVal && this.compute(upperBranch, nodeSolver, nodePrinter, strategy);
+        }
+        return retVal;
+    }
+
     /**
      * Should return the index of the (best) integer variable to branch on. Returning a negative index means
      * an integer solution has been found (no further branching). Does NOT return a global variable index -
